# import results
results <- read.csv("merge_mapping.csv", header = TRUE, sep = "\t", row.names = 1)

coverage <- as.table(results$COVERAGE)
source <-  results$SOURCE
name <- results$NAME
results <- results[,1:3]

png(filename="merge_mapping_barplot.png",res = 1200, pointsize = 5, width = 4, height = 4, units = "in")

# allow drawing in margins
par(xpd = NA,mar=c(10,12,4,2), lwd=0.5)

# create barplot with bar filling legend
plot <- barplot(t(as.matrix(results)), yaxt = "n", horiz=T,las=2, xlab = "Number of metabolites", cex.names=0.75, lwd=0.5, legend.text = TRUE, args.legend = list(x = "topright", bty = "n", legend=c("found in mass spectral databases","not found in mass spectral databases","ambiguous denomination")))

# add axis with model's organism names as label
axis(2,tick=FALSE, labels = name, at =plot,horiz=T,las=2,cex.names=0.75)

# add symbols for model's original database
points(x=rep(-100,length(plot)), y=plot, labels=coverage, col="black", cex=1, pch = c(15,16,17,18,19,20,21)[as.numeric(source)])

# add legend for database symboles
legend(x=100,y=-10,pch = c(15,16,17,18,19,20,21),legend=levels(source),bty ="n",ncol=4,cex=0.9)

# add coverage % in bars
text(plot, x=120, labels=coverage, col="white", cex=0.75)

dev.off()
